#
#-###################################################################
#
# Process Alpha Fields - eliminates invalid words. 
#
# This is a method for processing the alpha fields to eliminate titles.
# Using a method since the same processing is being performed for several 2D boxes.
#
# element		=> The element to be processed.
# field_length	=> The length of the processed (returned) field.
# no_titles		=> when 'true', titles are stripped off
# no_padding            => USED FOR TESTING....THIS STOPS THE SPACE PADDING SO WE CAN SHOOT
#                                THE 2D AND SEE THE EOD ON THE CORRECT LINE NUMBER. MAKE SURE THIS
#                                IS SET TO FALSE PRIOR TO RELEASING.
#
# We return the empty string if element is empty
#
# To get correct length, left-pads with spaces and appends to these whatever follows the space after
# an invalid title (with or without a following period.)  
#
def process_alpha_fields(element, field_length, no_titles, no_padding)

	element = element.upcase.strip
	return '' if (element.empty?)
	element = $'.strip if (element  =~ /^MR\.? |MS\.? |MRS\.? |MISS |DR\.? |REV\.? |PROF\.? /) if no_titles

	#
	# We have stripped out invalid titles & following space. If we are padding, we also ensure the return value is of the
	# proper length, padded in the front with space characters; otherwise, we just return the element for the length specified.
	#
	return (no_padding ? element[0,field_length] : (" " * ([field_length - element.length,0].max) + element[0,field_length]))
end
